@@ -14,12 +14,12 @@ ex_message                  text;
 v_adv_lock                  boolean;
 v_control                   text;
 v_drop_count                int := 0;
-v_id_position               int;
 v_index                     record;
 v_job_id                    bigint;
 v_jobmon                    boolean;
 v_jobmon_schema             text;
 v_max                       bigint;
+v_new_search_path           text := '@extschema@,pg_temp';
 v_old_search_path           text;
 v_parent_schema             text;
 v_parent_tablename          text;
@@ -92,13 +92,14 @@ ELSE
     END IF;
 END IF;
 
+SELECT current_setting('search_path') INTO v_old_search_path;
 IF v_jobmon THEN
-    SELECT nspname INTO v_jobmon_schema FROM pg_namespace n, pg_extension e WHERE e.extname = 'pg_jobmon' AND e.extnamespace = n.oid;
+    SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        SELECT current_setting('search_path') INTO v_old_search_path;
-        EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', '@extschema@,'||v_jobmon_schema, 'false');
+        v_new_search_path := '@extschema@,'||v_jobmon_schema||',pg_temp';
     END IF;
 END IF;
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
 
 IF p_keep_table IS NOT NULL THEN
     v_retention_keep_table = p_keep_table;
@@ -110,7 +111,10 @@ IF p_retention_schema IS NOT NULL THEN
     v_retention_schema = p_retention_schema;
 END IF;
 
-SELECT schemaname, tablename INTO v_parent_schema, v_parent_tablename FROM pg_catalog.pg_tables WHERE schemaname ||'.'|| tablename = p_parent_table;
+SELECT schemaname, tablename INTO v_parent_schema, v_parent_tablename
+FROM pg_catalog.pg_tables
+WHERE schemaname = split_part(p_parent_table, '.', 1)::name
+AND tablename = split_part(p_parent_table, '.', 2)::name;
 
 -- Loop through child tables starting from highest to get current max value in partition set
 -- Avoids doing a scan on entire partition set and/or getting any values accidentally in parent.
@@ -127,8 +131,9 @@ END LOOP;
 FOR v_row IN 
     SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(p_parent_table, 'ASC')
 LOOP
-    v_id_position := (length(v_row.partition_tablename) - position('p_' in reverse(v_row.partition_tablename))) + 2;
-    v_partition_id := substring(v_row.partition_tablename from v_id_position)::bigint;
+     SELECT child_start_id INTO v_partition_id FROM @extschema@.show_partition_info(v_row.partition_schemaname||'.'||v_row.partition_tablename
+        , v_partition_interval::text
+        , p_parent_table);
 
     -- Add one interval since partition names contain the start of the constraint period
     IF v_retention <= (v_max - (v_partition_id + v_partition_interval)) THEN
@@ -163,8 +168,8 @@ LOOP
                         SELECT c1.oid
                         FROM pg_catalog.pg_class c1
                         JOIN pg_catalog.pg_namespace n1 ON c1.relnamespace = n1.oid
-                        WHERE c1.relname = v_row.partition_tablename
-                        AND n1.nspname = v_row.partition_schema
+                        WHERE c1.relname = v_row.partition_tablename::name
+                        AND n1.nspname = v_row.partition_schema::name
                     )
                     SELECT c.relname as name
                         , con.conname
@@ -221,9 +226,10 @@ IF v_jobmon_schema IS NOT NULL THEN
         PERFORM update_step(v_step_id, 'OK', format('%s partitions dropped.', v_drop_count));
         PERFORM close_job(v_job_id);
     END IF;
-    EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
 END IF;
 
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
+
 RETURN v_drop_count;
 
 EXCEPTION
