@@ -21,6 +21,7 @@ CREATE TABLE part_config (
     , undo_in_progress boolean NOT NULL DEFAULT false
     , trigger_exception_handling BOOLEAN DEFAULT false
     , upsert text NOT NULL DEFAULT ''
+    , trigger_return_null boolean NOT NULL DEFAULT true
     , CONSTRAINT part_config_parent_table_pkey PRIMARY KEY (parent_table)
     , CONSTRAINT positive_premake_check CHECK (premake > 0)
 );
@@ -49,6 +50,7 @@ CREATE TABLE part_config_sub (
     , sub_jobmon boolean NOT NULL DEFAULT true
     , sub_trigger_exception_handling BOOLEAN DEFAULT false
     , sub_upsert TEXT NOT NULL DEFAULT ''
+    , sub_trigger_return_null boolean NOT NULL DEFAULT true
     , CONSTRAINT part_config_sub_pkey PRIMARY KEY (sub_parent)
     , CONSTRAINT part_config_sub_sub_parent_fkey FOREIGN KEY (sub_parent) REFERENCES @extschema@.part_config (parent_table) ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE INITIALLY DEFERRED
     , CONSTRAINT positive_premake_check CHECK (sub_premake > 0)
